Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects..

Actions, resources, and condition keys for AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects. - Service Authorization Reference

# Actions, resources, and condition keys for AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.

AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects. (service prefix: `apptest` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.
- Resource types defined by AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.
- Condition keys for AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.

## Actions defined by AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateTestCase | Grants permission to create a test case | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTestConfiguration | Grants permission to create a test configuration | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTestSuite | Grants permission to create a test suite | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteTestCase | Grants permission to delete a test case | Write | TestCase* |  |
DeleteTestConfiguration | Grants permission to delete a test configuration | Write | TestConfiguration* |  |
DeleteTestRun | Grants permission to delete a test run | Write | TestRun* |  | s3:DeleteObject s3:ListBucket
DeleteTestSuite | Grants permission to delete a test suite | Write | TestSuite* |  |
GetTestCase | Grants permission to get a test case | Read | TestCase* |  |
GetTestConfiguration | Grants permission to get a test configuration | Read | TestConfiguration* |  |
GetTestRunStep | Grants permission to get test run step | Read | TestRun* |  |
GetTestSuite | Grants permission to get a test suite | Read | TestSuite* |  |
ListTagsForResource | Grants permission to list tags for a resource | Read |  |  |
ListTestCases | Grants permission to list test cases | List |  |  |
ListTestConfigurations | Grants permission to list test configurations | List |  |  |
ListTestRunSteps | Grants permission to list steps for a test run | Read | TestRun* |  |
ListTestRunTestCases | Grants permission to list test cases for a test run | Read | TestRun* |  |
ListTestRuns | Grants permission to list test runs | List |  |  |
ListTestSuites | Grants permission to list test suites | List |  |  |
StartTestRun | Grants permission to start a test run | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | cloudformation:CreateStack cloudformation:DeleteStack cloudformation:DescribeStacks dms:DescribeReplicationTasks dms:StartReplicationTask dms:StopReplicationTask ec2:DescribeAvailabilityZones ec2:DescribeVpcEndpointServiceConfigurations ec2:DescribeVpcEndpointServices m2:CreateDataSetImportTask m2:GetApplication m2:GetBatchJobExecution m2:GetDataSetDetails m2:GetDataSetImportTask m2:StartApplication m2:StartBatchJob m2:StopApplication s3:CreateBucket s3:DeleteObject s3:GetObject s3:ListBucket s3:PutObject
TagResource | Grants permission to tag a resource | Tagging | TestCase |  |
TestConfiguration |  |
TestRun |  |
TestSuite |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag a resource | Tagging | TestCase |  |
TestConfiguration |  |
TestRun |  |
TestSuite |  |
| aws:TagKeys |
UpdateTestCase | Grants permission to update a test case | Write | TestCase* |  |
UpdateTestConfiguration | Grants permission to update a test configuration | Write | TestConfiguration* |  |
UpdateTestSuite | Grants permission to update a test suite | Write | TestSuite* |  |

## Resource types defined by AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
TestCase | `arn:$ { Partition}:apptest:$ { Region}:$ { Account}:testcase/$ { testCaseId}` | aws:ResourceTag/${TagKey}
TestConfiguration | `arn:$ { Partition}:apptest:$ { Region}:$ { Account}:testconfiguration/$ { testConfigurationId}` | aws:ResourceTag/${TagKey}
TestRun | `arn:$ { Partition}:apptest:$ { Region}:$ { Account}:testrun/$ { testRunId}` | aws:ResourceTag/${TagKey}
TestSuite | `arn:$ { Partition}:apptest:$ { Region}:$ { Account}:testsuite/$ { testSuiteId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects.

AWS Mainframe Modernization Application Testing provides tools and resources for automated functional equivalence testing for your migration projects. defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.